@@ -382,12 +382,8 @@ def pydantic_model_creator(
             description = comment or _br_it(fdesc.get("docstring") or fdesc["description"] or "")
             fconfig["description"] = description
             fconfig["title"] = fname.replace("_", " ").title()
-            if field_default is not None:
-                if callable(field_default):
-                    fconfig["default_factory"] = field_default
-                    properties[fname] = None
-                else:
-                    properties[fname] = field_default
+            if field_default is not None and not callable(field_default):
+                properties[fname] = field_default
             pconfig.fields[fname] = fconfig
 
     # Here we endure that the name is unique, but complete objects are still labeled verbatim
@@ -455,6 +451,7 @@ def pydantic_queryset_creator(
         computed=computed,
         allow_cycles=allow_cycles,
         sort_alphabetically=sort_alphabetically,
+        name=name,
     )
     lname = name or f"{submodel.__name__}_list"
 
